<?php
session_start();

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success' => false, 'error' => 'Método inválido. Apenas POST é permitido.']);
    http_response_code(405);
    exit();
}


$data = file_get_contents("php://input");
$parsedData = json_decode($data, true);

$cpf = isset($parsedData['cpf']) ? $parsedData['cpf'] : '';

if (empty($cpf)) {
    echo json_encode(['success' => false, 'error' => 'CPF é obrigatório.']);
    http_response_code(400);
    exit();
}

$url = 'https://api.dataget.tech/?api_key=VYFuOYCeZrUf&cpf=' . $cpf;

$header = [
    'Content-Type: application/json',
];

try {
    // Inicializa o cURL
    $ch = curl_init();    

    // Configurações da requisição
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $header);

    // Executa a requisição
    $response = curl_exec($ch);
    $http_status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    

    // Verifica se houve erro na execução
    if ($response === false) {
        $error = curl_error($ch);
        curl_close($ch);
        echo json_encode(['success' => false, 'error' => 'Erro de conexão: ' . $error]);
        http_response_code(500);
        exit();
    }

    // Fecha o cURL
    curl_close($ch);

    // Processa a resposta
    $result = json_decode($response, true);

    if ($http_status == 200 && isset($result['dados']['cpf'])) {
        echo json_encode([
            'success' => true,
            'data' => $result['dados'],
        ]);
    } else {
        $errorMessage = isset($result['message']) ? $result['message'] : 'Erro desconhecido.';
        echo json_encode([
            'success' => false,
            'error' => $errorMessage,
        ]);
        http_response_code($http_status);
    }
} catch (Exception $e) {
    echo json_encode([
        'success' => false,
        'error' => 'Erro inesperado: ' . $e->getMessage(),
    ]);
    http_response_code(500);
}
